#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppItemTemplateQueryModel(object):

    def __init__(self):
        self._business_model = None
        self._category_id = None
        self._item_type = None

    @property
    def business_model(self):
        return self._business_model

    @business_model.setter
    def business_model(self, value):
        self._business_model = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_model:
            if hasattr(self.business_model, 'to_alipay_dict'):
                params['business_model'] = self.business_model.to_alipay_dict()
            else:
                params['business_model'] = self.business_model
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.item_type:
            if hasattr(self.item_type, 'to_alipay_dict'):
                params['item_type'] = self.item_type.to_alipay_dict()
            else:
                params['item_type'] = self.item_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppItemTemplateQueryModel()
        if 'business_model' in d:
            o.business_model = d['business_model']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'item_type' in d:
            o.item_type = d['item_type']
        return o


